# Toolkit for data management and analysis

Hybra Core is a toolkit to work with data and helps to
* wrangle
* visualize
* analyze
the data.

Hybra Core is part of the [Hybra Data Analysis Ecosystem](http://research.cs.aalto.fi/dcc/output/hybra), supporting also data collection and processing.

# The toolkit

## Documentation

See [http://hybra.readthedocs.io/](http://hybra.readthedocs.io/en/latest/) for documentation and code examples.

## Contents

* core: the actual code for data management and analysis
* test: automated tests for data our library
* data: small example datasets
* docs: documentation

# Acknowledgements

## Background

We thank following funders for supporting this work

* Academy of Finland
   * Racisms and public communications in the hybrid media environment (HYBRA) project uses this tool as its primary computational data analysis environment.
* Kone Foundation
   * Matti Nelimarkka's work on mainstreaming this tool was supported by Digital Humanities of Public Policy Making.
* TEKES - the Finnish Funding Agency for Innovation
   * Smarter Social Media Analytics
* Sanoma Foundation
   * Early work towards this ecosystem was done in Digivaalit 2015 project.

## Authors

* Matti Nelimarkka (matti.nelimarkka@aalto.fi)
* Juho Pääkkönen (juho.paakkonen@aalto.fi)
* Arto Kekkonen (arto.kekkonen@helsinki.fi)
